@@ -298,6 +298,18 @@ GetChildValue(EbmlMaster *master) {
   return GetChild<Telement>(master).GetValue();
 }
 
+template<typename T>
+bool
+Is(EbmlElement *e) {
+  return !e ? false : (EbmlId(*e) == T::ClassInfos.GlobalId);
+}
+
+template<typename T1, typename T2, typename... Trest>
+bool
+Is(EbmlElement *e) {
+  return !e ? false : Is<T1>(e) || Is<T2, Trest...>(e);
+}
+
 EbmlElement *empty_ebml_master(EbmlElement *e);
 EbmlElement *create_ebml_element(const EbmlCallbacks &callbacks, const EbmlId &id);
 EbmlMaster *sort_ebml_master(EbmlMaster *e);
@@ -310,6 +322,7 @@ const EbmlCallbacks *find_ebml_parent_callbacks(const EbmlCallbacks &base, const
 const EbmlSemantic *find_ebml_semantic(const EbmlCallbacks &base, const EbmlId &id);
 
 EbmlElement *find_ebml_element_by_id(EbmlMaster *master, const EbmlId &id);
+std::pair<EbmlMaster *, size_t> find_element_in_master(EbmlMaster *master, EbmlElement *element_to_find);
 
 void fix_mandatory_elements(EbmlElement *master);
 
