@@ -20,32 +20,39 @@
 
 namespace ivf {
 
+enum codec_e {
+  UNKNOWN_CODEC,
+  VP8,
+  VP9,
+};
+
 #if defined(COMP_MSC)
 #pragma pack(push,1)
 #endif
-  struct PACKED_STRUCTURE file_header_t {
-    unsigned char file_magic[4];  // "DKIF"
-    uint16_t      version;
-    uint16_t      header_size;
-    unsigned char fourcc[4];      // "VP80"
-    uint16_t      width;
-    uint16_t      height;
-    uint32_t      frame_rate_num;
-    uint32_t      frame_rate_den;
-    uint32_t      frame_count;
-    uint32_t      unused;
+struct PACKED_STRUCTURE file_header_t {
+  unsigned char file_magic[4];  // "DKIF"
+  uint16_t      version;
+  uint16_t      header_size;
+  unsigned char fourcc[4];      // "VP80"
+  uint16_t      width;
+  uint16_t      height;
+  uint32_t      frame_rate_num;
+  uint32_t      frame_rate_den;
+  uint32_t      frame_count;
+  uint32_t      unused;
 
-    file_header_t();
-  };
+  file_header_t();
+  codec_e get_codec() const;
+};
 
-  struct PACKED_STRUCTURE frame_header_t {
-    uint32_t frame_size;
-    uint64_t timestamp;
+struct PACKED_STRUCTURE frame_header_t {
+  uint32_t frame_size;
+  uint64_t timestamp;
 
-    frame_header_t();
-  };
+  frame_header_t();
+};
 
-  bool is_keyframe(const memory_cptr &buffer);
+bool is_keyframe(const memory_cptr &buffer, codec_e codec);
 
 #if defined(COMP_MSC)
 #pragma pack(pop)
