@@ -404,6 +404,20 @@ generic_packetizer_c::set_track_enabled_flag(bool enabled_track) {
     GetChild<KaxTrackFlagEnabled>(m_track_entry).SetValue(enabled_track ? 1 : 0);
 }
 
+void
+generic_packetizer_c::set_track_seek_pre_roll(timecode_c const &seek_pre_roll) {
+  m_seek_pre_roll = seek_pre_roll;
+  if (m_track_entry)
+    GetChild<KaxSeekPreRoll>(m_track_entry).SetValue(seek_pre_roll.to_ns());
+}
+
+void
+generic_packetizer_c::set_codec_delay(timecode_c const &codec_delay) {
+  m_codec_delay = codec_delay;
+  if (m_track_entry)
+    GetChild<KaxCodecDelay>(m_track_entry).SetValue(codec_delay.to_ns());
+}
+
 void
 generic_packetizer_c::set_audio_sampling_freq(float freq) {
   m_haudio_sampling_freq = freq;
@@ -653,6 +667,12 @@ generic_packetizer_c::set_headers() {
   if (!boost::logic::indeterminate(m_ti.m_enabled_track))
     GetChild<KaxTrackFlagEnabled>(m_track_entry).SetValue(m_ti.m_enabled_track ? 1 : 0);
 
+  if (m_seek_pre_roll.valid())
+    GetChild<KaxSeekPreRoll>(m_track_entry).SetValue(m_seek_pre_roll.to_ns());
+
+  if (m_codec_delay.valid())
+    GetChild<KaxCodecDelay>(m_track_entry).SetValue(m_codec_delay.to_ns());
+
   if (track_video == m_htrack_type) {
     KaxTrackVideo &video = GetChild<KaxTrackVideo>(m_track_entry);
 
@@ -795,11 +815,8 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
 
   m_enqueued_bytes += pack->data->get_size();
 
-  if ((0 > pack->bref) && (0 <= pack->fref)) {
-    int64_t tmp = pack->bref;
-    pack->bref  = pack->fref;
-    pack->fref  = tmp;
-  }
+  if ((0 > pack->bref) && (0 <= pack->fref))
+    std::swap(pack->bref, pack->fref);
 
   if (1 != m_connected_to)
     add_packet2(pack);
@@ -816,8 +833,11 @@ generic_packetizer_c::add_packet2(packet_cptr pack) {
     pack->bref     = ADJUST_TIMECODE(pack->bref);
   if (pack->has_fref())
     pack->fref     = ADJUST_TIMECODE(pack->fref);
-  if (pack->has_duration())
-    pack->duration = (int64_t)(pack->duration * m_ti.m_tcsync.numerator / m_ti.m_tcsync.denominator);
+  if (pack->has_duration()) {
+    pack->duration = static_cast<int64_t>(pack->duration * m_ti.m_tcsync.numerator / m_ti.m_tcsync.denominator);
+    if (pack->has_discard_padding())
+      pack->duration -= std::min(pack->duration, pack->discard_padding.to_ns());
+  }
 
   if ((2 > m_htrack_min_cache) && pack->has_fref()) {
     set_track_min_cache(2);
@@ -887,6 +907,8 @@ generic_packetizer_c::get_packet() {
   packet_cptr pack = m_packet_queue.front();
   m_packet_queue.pop_front();
 
+  pack->output_order_timecode = timecode_c::ns(pack->assigned_timecode - std::max(m_codec_delay.to_ns(0), m_seek_pre_roll.to_ns(0)));
+
   m_enqueued_bytes -= pack->data->get_size();
 
   --m_next_packet_wo_assigned_timecode;
